@@ -1,8 +1,9 @@
 var EXPORTED_SYMBOLS = ["Comment"];
 Components.utils.import('resource://indexdata/util/xmlHelper.js');
 
-var Comment = function (body) {
+var Comment = function (body, block) {
   this.body = body || "";
+  this.block = block || null;
 };
 
 Comment.prototype.draw = function (surface) {
