@@ -5,6 +5,9 @@ Components.utils.import('resource://indexdata/util/xmlHelper.js');
 Components.utils.import('resource://indexdata/util/xulHelper.js');
 Components.utils.import('resource://indexdata/util/jsonPathHelper.js');
 Components.utils.import('resource://indexdata/runtime/Conditional.js');
+Components.utils.import('resource://indexdata/util/logging.js');
+
+var logger = logging.getLogger();
 
 var Skip = function () {
   this.conf = {};
@@ -160,8 +163,9 @@ Skip.prototype.upgrade = function (confVer, curVer, conf) {
 };
 
 Skip.prototype.getUsedArgs = function () {
-  return this.conditional.getUsedArgs;
-}
+  let args = this.conditional.getUsedArgs();
+  return args;
+};
 
 Skip.prototype.renderArgs = function () {
   return String(this.conditional);
