@@ -199,9 +199,11 @@ var testArray = [
       [ "SPAN $title [ @class = \"fooclass\" ] : BR ", 3, 6 ],
       
       // same test as above, with regex
-      [ "SPAN $title [ @class ~ \"fooclass\" ] : BR ", 3, 6 ],
+      //[ "SPAN $title [ @class ~ \"fooclass\" ] : BR ", 3, 6 ],
+      [ "SPAN $title [ @class ~ /fooclass/ ] : BR ", 3, 6 ],
       // real regex test
-      [ "SPAN $title [ @class ~ \"[fF].*?o+cl.s+\" ] : BR ", 3, 6 ],
+      //[ "SPAN $title [ @class ~ \"[fF].*?o+cl.s+\" ] : BR ", 3, 6 ],
+      [ "SPAN $title [ @class ~ /[fF].*?o+cl.s+/ ] : BR ", 3, 6 ],
 
 
       // Get all that match, save in $class
@@ -788,8 +790,8 @@ var testArray = [
     [
       [ "A [ /Shakespeare/ ]", 1, 0 ],
       [ "A [ /shakespeare/ ]", 0, 0 ],
-      [ "A $author [ @href ~ \"author=\" ]", 1, 2 ],
-      [ "A $title [ @href ~ \"title=\" ]", 1, 2 ],
+      [ "A $author [ @href ~ /author=/ ]", 1, 2 ],
+      [ "A $title [ @href ~ /title=/ ]", 1, 2 ],
       [ "A [ @href ~ \"/search.asp\?\" ]", 2, 0 ],
     ]
   ], // regex-attr
