@@ -225,31 +225,37 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
 
     if (pid > 0)
     {
-        int r = kill(pid, SIGTERM);
-        int x = errno;
-
-        if (m_logger)
+        while (1)
         {
+            int r = kill(pid, SIGTERM);
+            int x = errno;
+            if (m_logger)
+            {
+                if (r == -1)
+                    m_logger->printf("engine", YLOG_WARN,
+                                     "display: kill stale Xvfb PID=%ld: %s",
+                                     (long) pid, strerror(x));
+                else
+                    m_logger->printf("engine", YLOG_WARN,
+                                     "display: kill stale Xvfb PID=%ld",
+                                     (long) pid);
+            }
             if (r == -1)
-                m_logger->printf("engine", YLOG_WARN,
-                                 "display: kill stale Xvfb PID=%ld: %s",
-                                 (long) pid, strerror(x));
-            else
-                m_logger->printf("engine", YLOG_WARN,
-                                 "display: kill stale Xvfb PID=%ld",
-                                 (long) pid);
-        }
-        if (r == -1 && x != ESRCH)
-        {
-            wrbuf_printf(wrbuf_error, "display: unable to kill stale Xvfb "
-                         "PID=%ld: %s", (long) pid, strerror(x));
-            close();
-            return false;
-        }
-        if (r == 0)
-        {
-            int status;
-            waitpid(pid, &status, 0);
+            {
+                if (x == ESRCH)
+                    break; /* stale process is gone */
+                else
+                {
+                    wrbuf_printf(wrbuf_error, "display: unable to kill stale Xvfb "
+                                 "PID=%ld: %s", (long) pid, strerror(x));
+                    close();
+                    return false;
+                }
+            }
+            struct timespec req;
+            req.tv_sec = 0;
+            req.tv_nsec = 50000000; /* 1/20 sec */
+            ::nanosleep(&req, 0);
         }
     }
     wrbuf_printf(fname_log_file, "%s/Xvfb.%d.log", lockdir, display_base + dno);
@@ -266,7 +272,7 @@ bool CF_Display::lock_via_xvfb_cmd(const char *lockdir, const char *xvfb_cmd,
     else if (xvfb_pid == 0)
     {
         int i;
-        for (i = getdtablesize(); i >= 0; --i)
+        for (i = getdtablesize(); --i >= 0; )
             ::close(i);
 
         // stdin
