@@ -41,7 +41,8 @@ public:
 	      const char *proxy,
               const char *loglevel,
               CF_Logger *logger,
-              int fd);
+              int fd,
+              int capt_stdout);
 
     /**
      * Destructor
@@ -121,7 +122,7 @@ private:
               int argc, char **argv, const char *module_path,
               const char *app_path, const char *mozembed_path,
               const char *proxy, const char *loglevel,
-              CF_Logger *logger, int fd);
+              CF_Logger *logger, int fd, int capt_stdout);
 };
 
 /**
