@@ -361,7 +361,7 @@ WRBUF CF_Factory::get_cf_file(WRBUF username, WRBUF password, const char *db, in
 
 CF_Engine *CF_Factory::create(enum CF_Engine::Flags flags, const char *proxy,
                               const char *loglevel,
-                              CF_Logger *logger, int fd)
+                              CF_Logger *logger, int fd, int capt_stdout)
 {
     return new CF_Engine(
         flags,
@@ -371,7 +371,7 @@ CF_Engine *CF_Factory::create(enum CF_Engine::Flags flags, const char *proxy,
         proxy,
         loglevel,
         logger,
-        fd);
+        fd, capt_stdout);
 }
 
 void CF_Factory::auth(WRBUF username, WRBUF password, int *http_status)
